import CommentButton from "./comment-button";
import LikeButton from "./like-button";

type messageType = any // Prisma.PostUncheckedCreateInput
type messageItemProps = {
    msg: messageType;
};

export default function PostItem({ msg }: messageItemProps) {
    if (!msg.id) {
        return <div></div>;
    }
    return (
        <div className="flex border-b border-gray-200 py-4">
            <div className="flex-shrink-0">
                <div className="h-10 w-10 rounded-full bg-gray-300"></div> {/* Profile picture */}
            </div>
            <div className="ml-4 flex flex-col flex-grow">
                <div>
                    <div className="flex items-center">
                        <span className="font-bold mr-2">{msg.user.name}</span>
                        <span className="text-gray-500 text-sm">
                            {formatDate(new Date(msg.createdAt!))}
                        </span>
                    </div>
                    <div className="text-gray-800">{msg.content}</div>
                </div>
                <div className="mt-4 flex">
                    <div className="bg-gray-200 rounded-lg py-10 px-20 mr-2">
                        {/* potential Image */}
                    </div>
                </div>
                <div className="flex justify-end" >
                    <LikeButton data={msg} />
                    <CommentButton data={msg} />
                </div>
            </div>
        </div>
    )
};

function formatDate(date: Date) {
    return date.toLocaleDateString("en-US", {
        day: "numeric",
        month: "short",
        year: "numeric"
    });
}